summaryrefslogtreecommitdiff
path: root/fabfile.py
diff options
context:
space:
mode:
authorTodd Leonhardt <todd.leonhardt@gmail.com>2017-08-09 08:50:40 -0400
committerTodd Leonhardt <todd.leonhardt@gmail.com>2017-08-09 08:50:40 -0400
commit508088dbdfe5ba7dac077c1b3b60964b4ee0af16 (patch)
tree81325a65a1ccc7a5e09a6a0be831806151f4bf26 /fabfile.py
parent832f3ec312a04176676ea282b51a4e2284bf349b (diff)
downloadcmd2-git-508088dbdfe5ba7dac077c1b3b60964b4ee0af16.tar.gz
Renamed CHANGES.md to CHANGELOG.md
Just to make it that much more obvious what exactly it is ;-)
Diffstat (limited to 'fabfile.py')
-rw-r--r--fabfile.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/fabfile.py b/fabfile.py
index 88921550..d0989f3a 100644
--- a/fabfile.py
+++ b/fabfile.py
@@ -80,11 +80,11 @@ def release_check():
if 'a' in env.version:
print("WARNING: alpha release %s" % env.version)
- # hacky CHANGES.md check
- with open("CHANGES.md") as f:
+ # hacky CHANGELOG.md check
+ with open("CHANGELOG.md") as f:
raw_changes = f.read()
assert "%s\n---" % env.version in raw_changes, \
- "The current version %s is not in CHANGES.md" % env.version
+ "The current version %s is not in CHANGELOG.md" % env.version
if env.version in tags:
raise Exception("Already released v. %r" % env.version)